[][src]Struct style::values::computed::font::FontFamily

pub struct FontFamily {
    pub families: FontFamilyList,
    pub is_system_font: bool,
}

Specifies a prioritized list of font family names or generic family names.

Fields

families: FontFamilyList

The actual list of family names.

is_system_font: bool

Whether this font-family came from a specified system-font.

Implementations

impl FontFamily[src]

pub fn serif() -> Self[src]

Get default font family as serif which is a generic font-family